@@ -54,7 +54,7 @@ except ImportError:
     MAX_FONT_SIZE = 69
 
 
-__version__ = '0.1.10'
+__version__ = '0.1.11'
 
 
 class AutoFontSizeBehavior:
@@ -412,13 +412,12 @@ class SimpleAutoTickerBehavior:
 
         self._ticker_texture_width = self.width - self.auto_ticker_text_spacing
 
-        self._length_anim = Animation(_ticker_text_length=1, d=self.auto_ticker_length_anim_duration, t='out_quad')
+        self._length_anim = Animation(_ticker_text_length=9, d=self.auto_ticker_length_anim_duration, t='out_quad')
         self._length_anim.bind(on_progress=self._ticker_length_progress)
         self._length_anim.start(self)
 
     def _start_offset_anim(self, *_args):
-        self._offset_anim = Animation(_ticker_text_offset=self._ticker_text_offset * 2,
-                                      d=self.auto_ticker_offset_anim_duration)
+        self._offset_anim = Animation(_ticker_text_offset=0, d=self.auto_ticker_offset_anim_duration)
         self._offset_anim.bind(on_progress=self._ticker_offset_progress)
         self._offset_anim.start(self)
 
@@ -450,11 +449,11 @@ class SimpleAutoTickerBehavior:
             self._ticker_text_update(self.text[1:-1])
 
     def _ticker_max_offset(self):
-        return round(len(self._ori_text) + 1 - self._ticker_text_length)
+        return round(len(self._ori_text) - self._ticker_text_length)
 
     def _ticker_offset_progress(self, _anim: Animation, _self: Widget, progress: float):
         beg = int(self._ticker_text_offset)
-        end = beg + self._ticker_text_length
+        end = beg + int(self._ticker_text_length)
         self._ticker_text_update(self._ori_text[beg:end])
         if progress >= 1.0 and self._offset_anim:      # added `and self._offset_anim` for mypy
             self._offset_anim.stop(self)
